import React, { useState } from "react";
import PropTypes from "prop-types";
import {
  Accordion,
  AccordionSummary,
  AccordionDetails
} from "@material-ui/core";
import ExpandMoreIcon from "@material-ui/icons/ExpandMore";
import ReleaseNoteSummary from "./ReleaseNoteSummary";
import ReleaseNote from "./ReleaseNote";

const ReleaseNotesList = ({ releaseNotes }) => {
  const [flags, setFlags] = useState({});

  const handleToggle = key => (_, expanded) => {
    setFlags(prev => ({
      ...prev,
      [key]: expanded
    }));
  };

  const isCollapsed = key => {
    const expanded = flags[key];
    const collapsed = !expanded || expanded === false;
    return collapsed;
  };

  return (
    <>
      {releaseNotes.map(note => {
        return (
          <Accordion key={note.version} onChange={handleToggle(note.version)}>
            <AccordionSummary
              expandIcon={<ExpandMoreIcon />}
              id={`panel-${note.version}-header`}
            >
              <ReleaseNoteSummary
                releaseNote={note}
                collapsed={isCollapsed(note.version)}
              />
            </AccordionSummary>
            <AccordionDetails>
              <ReleaseNote releaseNote={note} />
            </AccordionDetails>
          </Accordion>
        );
      })}
    </>
  );
};

ReleaseNotesList.propTypes = {
  releaseNotes: PropTypes.array.isRequired
};

export default ReleaseNotesList;
